@@ -1,10 +1,8 @@
-import functools
-import re
-from typing import Any, Dict, List, Union
+from typing import Any, Dict
 
 from cognite.client._api_client import APIClient
 from cognite.client.data_classes import ContextualizationJob
-from cognite.client.utils._auxiliary import to_camel_case, to_snake_case
+from cognite.client.utils._auxiliary import to_camel_case
 from requests import Response
 
 
